@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12295 2020-06-02 19:01:46Z Trista $
+# $Id: cms_plugins.py 12330 2020-06-08 20:10:48Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-06-03 04:01:46 +0900 (週三, 03 六月 2020) $
-# $Revision: 12295 $
+# $Date: 2020-06-09 04:10:48 +0800 (週二, 09 六月 2020) $
+# $Revision: 12330 $
 
 import datetime
 
@@ -305,13 +305,14 @@ class CallToActionPlugin(CMSPluginBase):
                 redirectPage = thankNode.all()[0].cms_pages.all()[0]
             else:
                 
-                thankNode = TreeNode(site_id=obj.page.node.site_id)
+                thankNode = TreeNode(site_id=settings.SITE_ID, depth=1)
                 lan = obj.language
+                thankNode.save()
                 childPage = Page(node=thankNode, template=_settings.THANK_DEFAULT_TEMPLATE, created_by=request.user, 
                                  languages=lan)
                 childPage.save()
                 childTitle = Title(language=lan, title='Thank', slug='thank', page=childPage, 
-                                   path=f'{obj.page.title_set.all()[0].path}/thank')
+                                   path='thank')
                 childTitle.save()
                 childPage.publish(language=lan)
                 redirectPage = childPage
