@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12294 2020-06-02 19:00:43Z Trista $
+# $Id: views.py 12330 2020-06-08 20:10:48Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-06-03 04:00:43 +0900 (週三, 03 六月 2020) $
-# $Revision: 12294 $
+# $Date: 2020-06-09 04:10:48 +0800 (週二, 09 六月 2020) $
+# $Revision: 12330 $
 
 import datetime
 import hashlib
@@ -69,7 +69,7 @@ from Zephyrus.landing import ErrorCode
 from Zephyrus.landing.models import Email
 from Zephyrus.blog_extension.models import CallToActionModel, CallToActionStatistics
 from Zephyrus.blog_extension import settings as _settings
-from Iuppiter.DjangoUtil import getDowloadHttpResponse
+from Iuppiter.DjangoUtil import getDownloadHttpResponse
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -337,7 +337,11 @@ def showTargetFile(request):
             targetFile = callToActionStatistics.action.targetFile
 
             path = settings.MEDIA_URL + str(targetFile.file)
-            response = getDowloadHttpResponse(path[1:], name=callToActionStatistics.action.fileName)
+            response = getDownloadHttpResponse(
+                path[1:], 
+                name=callToActionStatistics.action.fileName, 
+                suffixIncluded=False
+            )
             return response
 
         elif callToActionStatistics.action.linkUrl:
@@ -355,8 +359,7 @@ def showTargetFile(request):
             if callToActionStatistics.article:
                 article = callToActionStatistics.article
                 articleId = int_to_hashid(article.pk)
-                name = f'[{websiteName}]{article.slug}'
-                fileName = f'{name}.pdf'
+                fileName = f'[{websiteName}]{article.slug}.pdf'
                 path = settings.MEDIA_URL + PDF_ROOT + fileName
                 
                 try:
@@ -384,8 +387,7 @@ def showTargetFile(request):
                 title = title.text.replace(' ', '')
                 title = title.replace('\n', '-')
                 
-                name = f"[{title}]"
-                fileName = f"{name}.pdf"
+                fileName = f"[{title}].pdf"
 
 
                 path = settings.MEDIA_URL + PDF_ROOT + fileName
@@ -396,7 +398,7 @@ def showTargetFile(request):
                     path[1:],
                     configuration=config,
                 )
-            response = getDowloadHttpResponse(path[1:], name=name)
+            response = getDownloadHttpResponse(path[1:], name=fileName, suffixIncluded=True)
             return response
 
     key = request.GET.get('key')
