@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_products.py 11848 2020-01-07 15:08:27Z Lavender $
+# $Id: build_products.py 11932 2020-02-18 17:50:41Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-01-07 23:08:27 +0800 (週二, 07 一月 2020) $
-# $Revision: 11848 $
+# $Date: 2020-02-19 01:50:41 +0800 (週三, 19 二月 2020) $
+# $Revision: 11932 $
 
 import os
 import sys
@@ -68,7 +68,8 @@ def createEnv(version):
             run("CreateEnv.bat %s" % version, 
                 shell=True, cwd=PROJECT_VIRTUALENV_DIR)
         else:
-            run("chmod +x CreateEnv.sh && ./CreateEnv.sh %s" % version, 
+            run(". $HOME/.bashrc && chmod +x $HOME/app/templates_shop/ZephyrusEnv/CreateEnv.sh && "
+                "source $HOME/app/templates_shop/ZephyrusEnv/CreateEnv.sh %s" % version, 
                 shell=True, cwd=PROJECT_VIRTUALENV_DIR)
 
     return (envPath, pythonPath)
@@ -127,7 +128,7 @@ class Command(BaseCommand):
             if 'Windows' in platform.system(): 
                 activateCommand = 'call activate "%s"' % (envPath,)
             else:
-                activateCommand = 'source activate "%s"' % (envPath,)
+                activateCommand = '. /home/nuwa/.bashrc && conda activate "%s"' % (envPath,)
 
             if not templateShop:
                 cmd = "python manage.py build_templates \"%s\" \"%s\" -o" % (
@@ -137,6 +138,7 @@ class Command(BaseCommand):
                         templateDir, dstPath)
 
             run("%s && %s" % (activateCommand, cmd), env=env, shell=True)
+            # run("%s" % (activateCommand, cmd), env=env, shell=True)
             with open(os.path.join(machinePath, 'BuildTemplates.log')) as log:
                 content = log.read()
             if content:
