@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 12021 2020-03-26 11:31:31Z Trista $
+# $Id: cms_dumpdata.py 12280 2020-05-28 08:02:42Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $
-# $Date: 2020-03-26 19:31:31 +0800 (週四, 26 三月 2020) $
-# $Revision: 12021 $
+# $Author: Lavender $
+# $Date: 2020-05-28 16:02:42 +0800 (週四, 28 五月 2020) $
+# $Revision: 12280 $
 
 import os
 import sys
@@ -88,7 +88,7 @@ class Command(BaseCommand):
             os.system(
                 ("%s manage.py dumpdata "
                  "-e auth -e sites -e filer -e "
-                 "contenttypes -e cms.Treenode"
+                 "contenttypes -e cms.Treenode -e statistics"
                  "> otherData.json") % 
                  sys.executable)
         
@@ -119,9 +119,10 @@ class Command(BaseCommand):
 
             path = os.path.join(options['path'])
 
-            with open(path, 'w') as f:
+            with open(path, 'w', encoding="utf-8") as f:
                 try:
-                    content = f.write(json.dumps(data))
+                    content = f.write(
+                        json.dumps(data, indent=4, ensure_ascii=False, default=str))
                 except Exception as e:
                     if os.path.exists(path):
                         os.remove(path)
